@@ -55,7 +55,7 @@ class ArgumentDependencyInjector:
         Raises:
             MissingDependency: no dependency was registered for `name`.
         """
-        args, varargs, keywords, defaults = inspect.getargspec(func)
+        args, varargs, keywords, defaults, *_ = inspect.getfullargspec(func)
         signature = inspect.signature(func)
 
         # For instance methods, ignore the self argument.
